@@ -1,6 +1,5 @@
-
-def score(source_data : list, weights : list, *args) -> list:
-    """Analyse data file using a range based procentual proximity
+def score(source_data: list, weights: list, get_scores=False, get_score_lists=False) -> list:
+    """Analyse data file using a range based percentual proximity
     algorithm and calculate the linear maximum likelihood estimation.
 
     Args:
@@ -10,25 +9,21 @@ def score(source_data : list, weights : list, *args) -> list:
             1 if higher values have higher weight in the data set
 
     Optional args:
-        "score_lists" (str): Returns a list with lists of each column scores.
-        "scores" (str): Returns only the final scores.
+        get_scores (bool): Returns only the final scores.
+        get_score_lists (bool): Returns a list with lists of each column scores.
 
     Raises:
-        ValueError: Weights can only be either 0 or 1 (int)
+        ValueError: Weights can only be either 0 or 1
 
     Returns:
         list: Source data with the score of the set appended at as the last element.
     """
 
     # getting data
-    data_lists = []
+    data_lists = [[] for i in source_data]
     for item in source_data:
         for i, val in enumerate(item):
-            try:
-                data_lists[i].append(float(val))
-            except IndexError:
-                data_lists.append([])
-                data_lists[i].append(float(val))
+            data_lists[i].append(float(val))
 
     # calculating price score
     score_lists = []
@@ -39,16 +34,16 @@ def score(source_data : list, weights : list, *args) -> list:
         score = []
         if weight == 0:
             for item in dlist:
-                try:
+                if not maxd - mind == 0:
                     score.append(1 - ((item - mind) / (maxd - mind)))
-                except ZeroDivisionError:
+                else:
                     score.append(1)
 
         elif weight == 1:
             for item in dlist:
-                try:
+                if not maxd - mind == 0:
                     score.append((item - mind) / (maxd - mind))
-                except ZeroDivisionError:
+                else:
                     score.append(0)
 
         else:
@@ -56,10 +51,6 @@ def score(source_data : list, weights : list, *args) -> list:
 
         score_lists.append(score)
 
-    # return score lists
-    if "score_lists" in args:
-        return score_lists
-
     # initialize final scores
     final_scores = [0 for i in range(len(score_lists[0]))]
 
@@ -68,18 +59,22 @@ def score(source_data : list, weights : list, *args) -> list:
         for j, ele in enumerate(slist):
             final_scores[j] = final_scores[j] + ele
 
-    # return only scores
-    if "scores" in args:
-        return final_scores
-
     # append scores to source data
     for i, ele in enumerate(final_scores):
         source_data[i].append(ele)
 
+    # return score lists
+    if get_score_lists:
+        return score_lists
+    # return only scores
+    if get_scores:
+        return final_scores
+    # return source data with appended scores
     return source_data
 
-def score_columns(source_data : list, columns : list, weights : list) -> list:
-    """Analyse data file using a range based procentual proximity
+
+def score_columns(source_data: list, columns: list, weights: list) -> list:
+    """Analyse data file using a range based percentual proximity
     algorithm and calculate the linear maximum likelihood estimation.
 
     Args:
@@ -96,14 +91,12 @@ def score_columns(source_data : list, columns : list, weights : list) -> list:
         list: Source data with the score of the set appended at as the last element.
     """
 
-    temp_data = []
-    for item in source_data:
-        temp_data.append([item[c] for c in columns])
+    temp_data = [[item[c] for c in columns] for item in source_data]
 
     if len(weights) > len(columns):
         weights = [weights[item] for item in columns]
 
-    for i, sc in enumerate(score(temp_data, weights, 'scores')):
+    for i, sc in enumerate(score(temp_data, weights, get_scores=True)):
         source_data[i].append(sc)
 
     return source_data
